@@ -385,12 +385,12 @@ To perform a non-flat erosion, @var{SE} must be a strel object.\n\
 The size of the result is determined by the optional @var{shape} argument\n\
 which takes the following values:\n\
 \n\
-@table @samp\n\
+@table @asis\n\
 @item @qcode{\"same\"} (default)\n\
 Return image of the same size as input @var{im}.\n\
 \n\
 @item @qcode{\"full\"}\n\
-Return the full erosion (image is padded to accomodate @var{se} near the\n\
+Return the full erosion (image is padded to accommodate @var{se} near the\n\
 borders).\n\
 \n\
 @item @qcode{\"valid\"}\n\
@@ -699,12 +699,12 @@ To perform a non-flat dilation, @var{SE} must be a strel object.\n\
 The size of the result is determined by the optional @var{shape} argument\n\
 which takes the following values:\n\
 \n\
-@table @samp\n\
+@table @asis\n\
 @item @qcode{\"same\"} (default)\n\
 Return image of the same size as input @var{im}.\n\
 \n\
 @item @qcode{\"full\"}\n\
-Return the full dilation (matrix is padded to accomodate @var{se} near the\n\
+Return the full dilation (matrix is padded to accommodate @var{se} near the\n\
 borders).\n\
 \n\
 @item @qcode{\"valid\"}\n\
